"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pathsMapper = void 0;
const JsonSchemaMapperContainer_1 = require("../registries/JsonSchemaMapperContainer");
const buildPath_1 = require("../utils/buildPath");
const concatParameters_1 = require("../utils/concatParameters");
const getJsonEntityStore_1 = require("../utils/getJsonEntityStore");
const getJsonPathParameters_1 = require("../utils/getJsonPathParameters");
const getOperationsStores_1 = require("../utils/getOperationsStores");
function operationId(path, { store, operationIdFormatter }) {
    return operationIdFormatter(store.parent.schema.get("name") || store.parent.targetName, store.propertyName, path);
}
function pushToPath(paths, { path, method, operation }) {
    return {
        ...paths,
        [path]: {
            ...paths[path],
            [method.toLowerCase()]: operation
        }
    };
}
function removeHiddenOperation(operationStore) {
    return !operationStore.store.get("hidden");
}
function mapOperationPaths({ operationStore, operation }) {
    return [...operationStore.operation.operationPaths.values()]
        .map((operationPath) => {
        return {
            ...operationPath,
            operationStore,
            operation
        };
    })
        .filter(({ method }) => method);
}
function mapOperationInPathParameters(options) {
    return ({ path, method, operation, operationStore }) => {
        return (0, getJsonPathParameters_1.getJsonPathParameters)(options.ctrlRootPath, path).map(({ path, parameters }) => {
            path = path ? path : "/";
            parameters = (0, concatParameters_1.concatParameters)(parameters.map(({ type, ...param }) => {
                return {
                    ...param,
                    schema: {
                        type
                    }
                };
            }), operation);
            return {
                operation: {
                    ...operation,
                    parameters,
                    operationId: operation.operationId ||
                        operationId(path, {
                            ...options,
                            store: operationStore
                        })
                },
                method,
                path
            };
        });
    };
}
function mapOperation(options) {
    return (operationStore) => {
        const operation = (0, JsonSchemaMapperContainer_1.execMapper)("operation", operationStore.operation, options);
        return {
            operation,
            operationStore
        };
    };
}
function pathsMapper(model, { paths, rootPath, ...options }) {
    const store = (0, getJsonEntityStore_1.getJsonEntityStore)(model);
    const ctrlPath = store.path;
    const ctrlRootPath = (0, buildPath_1.buildPath)(rootPath + ctrlPath);
    options = {
        ...options,
        ctrlRootPath
    };
    return [...(0, getOperationsStores_1.getOperationsStores)(model).values()]
        .filter(removeHiddenOperation)
        .map(mapOperation(options))
        .flatMap(mapOperationPaths)
        .flatMap(mapOperationInPathParameters(options))
        .reduce(pushToPath, paths);
}
exports.pathsMapper = pathsMapper;
(0, JsonSchemaMapperContainer_1.registerJsonSchemaMapper)("paths", pathsMapper);
//# sourceMappingURL=pathsMapper.js.map