"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MaxItems = void 0;
const withErrorMsg_1 = require("../../utils/withErrorMsg");
const jsonEntityFn_1 = require("../common/jsonEntityFn");
/**
 * The value `maxItems` MUST be a non-negative integer.
 *
 * An array instance is valid against `maxItems` if its size is less than, or equal to, the value of this keyword.
 *
 * :: warning
 * The value `maxItems` MUST be a non-negative integer.
 * :::
 *
 * :: warning
 * This decorator will be removed in v7.
 * For v6 user, use @@MaxItems@@ from @tsed/schema instead of @tsed/common.
 * :::
 *
 * ## Example
 *
 * ```typescript
 * class Model {
 *    @CollectionOf(String)
 *    @MaxItems(10)
 *    property: string[];
 * }
 * ```
 *
 * Will produce:
 *
 * ```json
 * {
 *   "type": "object",
 *   "properties": {
 *     "property": {
 *       "type": "number",
 *       "maxItems": 10
 *     }
 *   }
 * }
 * ```
 *
 * @param {number} maxItems
 * @decorator
 * @validation
 * @swagger
 * @schema
 * @input
 * @collections
 * @ajv-errors
 */
exports.MaxItems = (0, withErrorMsg_1.withErrorMsg)("maxItems", (maxItems) => {
    if (maxItems < 0) {
        throw new Error("The value of maxItems MUST be a non-negative integer.");
    }
    return (0, jsonEntityFn_1.JsonEntityFn)((storedJson) => {
        storedJson.schema.maxItems(maxItems);
    });
});
//# sourceMappingURL=maxItems.js.map