"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Nullable = void 0;
const core_1 = require("@tsed/core");
const any_1 = require("./any");
const property_1 = require("./property");
/**
 * Set field as nullable.
 *
 * ## Example
 *
 * ```typescript
 * class Model {
 *    @Nullable(Date)
 *    property: Date | null;
 *
 *    @Nullable(String, Number, Boolean)
 *    property: string | number | boolean | null;
 * }
 * ```
 *
 * @returns {Function}
 * @decorator
 * @validation
 * @swagger
 * @schema
 * @input
 */
function Nullable(type, ...types) {
    types = [type, ...types];
    return (0, core_1.useDecorators)(types.length === 1 && (0, property_1.Property)(types[0]), (0, any_1.Any)(null, ...types));
}
exports.Nullable = Nullable;
//# sourceMappingURL=nullable.js.map