import { JsonRequestBody } from "../domain/JsonRequestBody.js";
import { JsonSchema } from "../domain/JsonSchema.js";
import { execMapper, registerJsonSchemaMapper } from "../registries/JsonSchemaMapperContainer.js";
function buildSchemaFromBodyParameters(parameters, options) {
    let schema = new JsonSchema();
    const props = {};
    const refs = [];
    let propsLength = 0;
    parameters.forEach((parameter) => {
        const name = parameter.getName();
        [...parameter.entries()]
            .filter(([key]) => !["in", "name"].includes(key))
            .forEach(([key, value]) => {
            if (props[key] === undefined) {
                props[key] = value;
            }
        });
        const jsonParameter = execMapper("operationInParameter", parameter, options);
        if (name) {
            schema.addProperty(name, jsonParameter.schema || {
                type: jsonParameter.type
            });
            if (parameter.get("required")) {
                schema.addRequired(name);
            }
            propsLength++;
        }
        else {
            refs.push(jsonParameter);
        }
    });
    if (!propsLength) {
        if (refs.length === 1) {
            return refs[0];
        }
    }
    schema.type("object");
    return {
        schema: schema.toJSON(options),
        required: false,
        ...props
    };
}
export function operationRequestBodyMapper(bodyParameters, { consumes, ...options }) {
    const { schema, examples, in: _, ...props } = buildSchemaFromBodyParameters(bodyParameters, options);
    const requestBody = new JsonRequestBody(props);
    consumes.forEach((consume) => {
        requestBody.addContent(consume, schema, examples);
    });
    return execMapper("map", requestBody, options);
}
registerJsonSchemaMapper("operationRequestBody", operationRequestBodyMapper);
//# sourceMappingURL=operationRequestBodyMapper.js.map